### `BarChart` 组件

> 使用时建议配置个config.js文件来引入

| 参数名称 | 描述 | 类型 | 属性值 | 默认值|
|---|---|---|---|---|
|   | 提供了类似`css`缩写方式快捷设置 `Flex` 属性 | `String` | `1 row` |
| customStyle | 自定义图表配置 | `PropTypes.object` | `--` |
| customStyle.width | 每个柱子的宽度 | `number `| `必填`
| customStyle.height | 图表容器的高度 | `number `| `必填`
| customStyle.axisYWidth | 定义左面Y轴的宽度 | `number` | `必填`
| customStyle.fillColor | 柱状图的前景填充色 | `string `| `必填`
| customStyle.backgroundColor | 柱状图底色背景 | `string `| `必填`
| customStyle.raduis | 柱状图样式的圆角 | `number `| `必填`
| customStyle.parity | `odd`x轴奇数数据显示 `even`x轴偶数数据显示 `all`x轴数据全部显示 | `string `| `必填`
| customStyle.piecewise |  Y轴度量分几段 | `number `| `必填`
| customStyle.topAxisXShow | 是否展示顶部数据条显示value值 | `bool `| `必填`
| customStyle.showAxisY |  Y轴度量分几段 | `bool `| `必填`
| customStyle.showAxisXLine | 是否显示分段线 | `bool `| `必填`
| customStyle.showTopBar | 是否显示顶部数值条 | `bool `| `必填`
| customStyle.borderColor | 表格边框 | `string `| `必填`
| customStyle.textColor | 文本的颜色 | `string `| `必填`
| customStyle.topTextColor | 顶部文字颜色 | `string `| `必填`
| customStyle.unitName | 设置 AxisX 的度量单位 | `string` | `必填`
| customStyle.onClick  | 点击每个小柱子的回调click函数,目前业务只返回dataSource.data | `func` | `选填`
| dataSource | 数据源数组 | `PropTypes.array` | [{x:, y:, id:,}] | `--` |



```jsx
  static propTypes = {
    customStyle: PropTypes.object,
    dataSource: PropTypes.array,
  }
```

```jsx
  static defaultProps = {
    customStyle: {},
    dataSource: [],
  }
```


### demoe sample

```
    class ChartBarDemo extends Component {
  render() {
    const customStyle = {
      width: 10, // 每个柱子的宽度
      height: 180, // 图表容器的高度
      axisYWidth: 25, // 左面Y轴的宽度定义
      fillColor: '#82A0FA', // 柱状图的前景填充色
      backgroundColor: '#EBEDF1', // 柱状图底色背景
      raduis: 5, // 样式的圆角
      parity: 'even', // odd奇数显示 even偶数显示 all全部显示
      piecewise: 10, // Y轴度量分几段
      topAxisXShow: true, // 是否展示顶部对应的value值
      showAxisY: true, // 是否展示Y轴
      showAxisXLine: true, // 是否显示分段线
      showTopBar: true, // 是否显示顶部数值条
      borderColor: '#DCDEE5', // 表格边框
      chartStyle: { // x轴距离顶部距离
        marginTop: 10,
      },
      textStyle: {
        color: '#888', // 文本的样式
        fontSize: 10,
      },
      topTextStyle: { // 顶部文字样式
        color: 'red',
        fontSize: 14,
      },
      onClick: (obj) => { // 点击回调函数
        console.log(obj);  // {id:xxx}
      },
    };
    const dataSource = [
      { x: 8, value: 7, id: 12 },
      { x: 9, value: 10, id: 13 },
      { x: 10, value: 50, id: 14 },
      { x: 11, value: 16, id: 15 },
      { x: 12, value: 89, id: 16 },
      { x: 13, value: 99, id: 17 },
      { x: 14, value: 99, id: 18 },
      { x: 15, value: 100, id: 19 },
    ];
    return (
      <BarChart dataSource={dataSource} customStyle={customStyle} />
    );
  }
}
export default ChartBarDemo;
```
